=============================
 zope.security Documentation
=============================

Narrative Documentation
=======================

.. toctree::
   :maxdepth: 2

   narr
   example
   proxy
   hacking

API Reference
=============

.. toctree::
   :maxdepth: 2

   api/interfaces
   api/adapter
   api/checker
   api/decorator
   api/management
   api/permission
   api/protectclass
   api/proxy
   api/simplepolicies
   api/testing
   api/metaconfigure
   api/zcml


====================
 Indices and tables
====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
